@@ -29,9 +29,18 @@ sub new {
 		"--no-daemon",
 		"--refresh-dependencies",
 		"--gradle-user-home", ".gradle",
+		"-Duser.home=.",
+		"-Duser.name=debian",
 	#	"--init-script", "/usr/share/gradle-debian-helper/init.gradle",
 		);	
 
+	my $numthreads = $this->get_parallel();
+	if ($numthreads == -1) {
+		push(@{$this->{gradle_cmd}}, "--parallel");
+	} elsif ($numthreads > 1) {
+		push(@{$this->{gradle_cmd}}, "--parallel", "--max-workers=$numthreads");
+	}
+
 	return $this;
 }
 
@@ -53,7 +62,7 @@ sub clean {
 	my $this=shift;
 
 	$this->doit_in_builddir("find . -wholename .*build/tmp | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
-	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle");
+	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle", ".m2");
 }
 
 1
